asr.bandstructure
=================

.. automodule:: asr.bandstructure

   
   
   .. rubric:: Functions

   
   .. autofunction:: add_bs_pbe
   .. autofunction:: bs_pbe
   .. autofunction:: bs_pbe_html
   .. autofunction:: plot_with_colors
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   